pub struct Recipe {
pub headers: Vec<HeaderRecipe>,
pub body: BodyRecipe,
}Fields
headers: Vec<HeaderRecipe>body: BodyRecipeImplementations
Sourceimpl Recipe
impl Recipe
Sourcepub fn diff(
original: &AuthenticatedMessage<'_>,
modified: &AuthenticatedMessage<'_>,
) -> Recipe
pub fn diff( original: &AuthenticatedMessage<'_>, modified: &AuthenticatedMessage<'_>, ) -> Recipe
Generates the recipe that turns modified back into original.
Sourcepub fn apply(&self, headers: &[(&[u8], &[u8])], body: &[u8]) -> Result<Vec<u8>>
pub fn apply(&self, headers: &[(&[u8], &[u8])], body: &[u8]) -> Result<Vec<u8>>
Applies this recipe to reconstruct the previous message state.
pub fn to_json(&self, out: &mut Vec<u8>) -> Result<()>
pub fn from_json(bytes: &[u8]) -> Result<Recipe>