Dkim2Output

Struct Dkim2Output 

pub struct Dkim2Output<'x> { /* private fields */ }

Implementations

Source

impl<'x> Dkim2Output<'x>

pub fn result(&self) -> &Dkim2Result

pub fn chain(&self) -> &[ChainLink<'x>]

pub fn error(&self) -> Option<&Error>

pub fn failure_reason(&self) -> Option<String>

pub fn feedback_requested(&self) -> bool

Returns true if any signer in the verified chain requested feedback (the feedback flag, draft-ietf-dkim-dkim2-spec-03 8.10).

pub fn feedback_domains(&self) -> Vec<&str>

Domains (d=) of the signatures that requested feedback.

pub fn feedback_relay(&self) -> Option<&str>

If a privacy-conscious Forwarder set the feedhere flag, returns the domain of the most recent such hop, via which feedback should be relayed instead of being sent directly to the requestor (8.10). Otherwise None.