Dkim2Signer

Struct Dkim2Signer 

pub struct Dkim2Signer<State = NeedDomain> {
    pub keys: Vec<KeyEntry>,
    pub domain: String,
    pub flags: Vec<Flag>,
    pub nonce: Option<String>,
    /* private fields */
}

Fields

keys: Vec<KeyEntry>domain: Stringflags: Vec<Flag>nonce: Option<String>

Implementations

Source

impl Dkim2Signer<NeedDomain>

pub fn from_key(key: impl Into<DkimKey>) -> Dkim2Signer<NeedDomain>

pub fn domain(self, domain: impl Into<String>) -> Dkim2Signer<NeedSelector>

Sets the domain to use for signing.

Source

impl Dkim2Signer<NeedSelector>

pub fn selector(self, selector: impl Into<String>) -> Dkim2Signer<Done>

Sets the selector to use for signing.

Source

impl Dkim2Signer<Done>

pub fn additional_key( self, key: impl Into<DkimKey>, selector: impl Into<String>, ) -> Self

Adds an additional signing key and selector.

pub fn flags(self, flags: impl IntoIterator<Item = Flag>) -> Self

Sets the flags (f= tag) to add to the signature.

pub fn nonce(self, nonce: impl Into<String>) -> Self

Sets the nonce (n= tag) to add to the signature.

Source

impl Dkim2Signer<Done>

pub fn sign<'x, M, A, R, I>( &self, message: M, hop: Hop<A, R, I>, ) -> Result<Dkim2Signed>
where M: TryInto<AuthenticatedMessage<'x>, Error = Error>, A: AsRef<str>, R: IntoIterator<Item: AsRef<str>>, I: Into<String>,

Signs a message whose content has not changed (Originator or transparent Forwarder). Adds a DKIM2-Signature, and a Message-Instance only if none is present yet.

pub fn sign_revised<'x, O, M, A, R, I>( &self, original: O, modified: M, hop: Hop<A, R, I>, ) -> Result<Dkim2Signed>
where O: TryInto<AuthenticatedMessage<'x>, Error = Error>, M: TryInto<AuthenticatedMessage<'x>, Error = Error>, A: AsRef<str>, R: IntoIterator<Item: AsRef<str>>, I: Into<String>,

Signs a message whose content changed, computing the recipe by diffing original against modified (the form to be sent).

pub fn sign_with_recipe<'x, M, A, R, I>( &self, modified: M, recipe: Recipe, hop: Hop<A, R, I>, ) -> Result<Dkim2Signed>
where M: TryInto<AuthenticatedMessage<'x>, Error = Error>, A: AsRef<str>, R: IntoIterator<Item: AsRef<str>>, I: Into<String>,

Signs a changed message using a caller-supplied recipe describing how to reconstruct the previous state from modified.

pub fn sign_with_message_instance<'x, A, R, I>( &self, modified: &AuthenticatedMessage<'x>, instance: Option<&MessageInstance>, hop: Hop<A, R, I>, ) -> Result<Signature>
where A: AsRef<str>, R: IntoIterator<Item: AsRef<str>>, I: Into<String>,

Signs a message with a caller-supplied Message-Instance header.