pub struct Dkim2Signer<State = NeedDomain> {
pub keys: Vec<KeyEntry>,
pub domain: String,
pub flags: Vec<Flag>,
pub nonce: Option<String>,
/* private fields */
}Fields
keys: Vec<KeyEntry>domain: Stringflags: Vec<Flag>nonce: Option<String>Implementations
Sourceimpl Dkim2Signer<NeedDomain>
impl Dkim2Signer<NeedDomain>
pub fn from_key(key: impl Into<DkimKey>) -> Dkim2Signer<NeedDomain>
Sourcepub fn domain(self, domain: impl Into<String>) -> Dkim2Signer<NeedSelector>
pub fn domain(self, domain: impl Into<String>) -> Dkim2Signer<NeedSelector>
Sets the domain to use for signing.
Sourceimpl Dkim2Signer<Done>
impl Dkim2Signer<Done>
Sourcepub fn additional_key(
self,
key: impl Into<DkimKey>,
selector: impl Into<String>,
) -> Self
pub fn additional_key( self, key: impl Into<DkimKey>, selector: impl Into<String>, ) -> Self
Adds an additional signing key and selector.
Sourcepub fn flags(self, flags: impl IntoIterator<Item = Flag>) -> Self
pub fn flags(self, flags: impl IntoIterator<Item = Flag>) -> Self
Sets the flags (f= tag) to add to the signature.
Sourceimpl Dkim2Signer<Done>
impl Dkim2Signer<Done>
Sourcepub fn sign<'x, M, A, R, I>(
&self,
message: M,
hop: Hop<A, R, I>,
) -> Result<Dkim2Signed>where
M: TryInto<AuthenticatedMessage<'x>, Error = Error>,
A: AsRef<str>,
R: IntoIterator<Item: AsRef<str>>,
I: Into<String>,
pub fn sign<'x, M, A, R, I>(
&self,
message: M,
hop: Hop<A, R, I>,
) -> Result<Dkim2Signed>where
M: TryInto<AuthenticatedMessage<'x>, Error = Error>,
A: AsRef<str>,
R: IntoIterator<Item: AsRef<str>>,
I: Into<String>,
Signs a message whose content has not changed (Originator or transparent Forwarder). Adds a DKIM2-Signature, and a Message-Instance only if none is present yet.
Sourcepub fn sign_revised<'x, O, M, A, R, I>(
&self,
original: O,
modified: M,
hop: Hop<A, R, I>,
) -> Result<Dkim2Signed>where
O: TryInto<AuthenticatedMessage<'x>, Error = Error>,
M: TryInto<AuthenticatedMessage<'x>, Error = Error>,
A: AsRef<str>,
R: IntoIterator<Item: AsRef<str>>,
I: Into<String>,
pub fn sign_revised<'x, O, M, A, R, I>(
&self,
original: O,
modified: M,
hop: Hop<A, R, I>,
) -> Result<Dkim2Signed>where
O: TryInto<AuthenticatedMessage<'x>, Error = Error>,
M: TryInto<AuthenticatedMessage<'x>, Error = Error>,
A: AsRef<str>,
R: IntoIterator<Item: AsRef<str>>,
I: Into<String>,
Signs a message whose content changed, computing the recipe by diffing
original against modified (the form to be sent).
Sourcepub fn sign_with_recipe<'x, M, A, R, I>(
&self,
modified: M,
recipe: Recipe,
hop: Hop<A, R, I>,
) -> Result<Dkim2Signed>where
M: TryInto<AuthenticatedMessage<'x>, Error = Error>,
A: AsRef<str>,
R: IntoIterator<Item: AsRef<str>>,
I: Into<String>,
pub fn sign_with_recipe<'x, M, A, R, I>(
&self,
modified: M,
recipe: Recipe,
hop: Hop<A, R, I>,
) -> Result<Dkim2Signed>where
M: TryInto<AuthenticatedMessage<'x>, Error = Error>,
A: AsRef<str>,
R: IntoIterator<Item: AsRef<str>>,
I: Into<String>,
Signs a changed message using a caller-supplied recipe describing how to
reconstruct the previous state from modified.
Sourcepub fn sign_with_message_instance<'x, A, R, I>(
&self,
modified: &AuthenticatedMessage<'x>,
instance: Option<&MessageInstance>,
hop: Hop<A, R, I>,
) -> Result<Signature>
pub fn sign_with_message_instance<'x, A, R, I>( &self, modified: &AuthenticatedMessage<'x>, instance: Option<&MessageInstance>, hop: Hop<A, R, I>, ) -> Result<Signature>
Signs a message with a caller-supplied Message-Instance header.